@@ -176,22 +176,23 @@ renv_lockfile_create <- function(project,
                                  packages = NULL,
                                  exclude = NULL,
                                  prompt = NULL,
-                                 force = NULL)
+                                 force = NULL,
+                                 dev = FALSE)
 {
   libpaths <- libpaths %||% renv_libpaths_all()
   type <- type %||% settings$snapshot.type(project = project)
 
   # use a restart, so we can allow the user to install packages before snapshot
   lockfile <- withRestarts(
-    renv_lockfile_create_impl(project, type, libpaths, packages, exclude, prompt, force),
+    renv_lockfile_create_impl(project, type, libpaths, packages, exclude, prompt, force, dev = dev),
     renv_recompute_records = function() {
       renv_dynamic_reset()
-      renv_lockfile_create_impl(project, type, libpaths, packages, exclude, prompt, force)
+      renv_lockfile_create_impl(project, type, libpaths, packages, exclude, prompt, force, dev = dev)
     }
   )
 }
 
-renv_lockfile_create_impl <- function(project, type, libpaths, packages, exclude, prompt, force) {
+renv_lockfile_create_impl <- function(project, type, libpaths, packages, exclude, prompt, force, dev = FALSE) {
 
   lockfile <- renv_lockfile_init(project)
 
@@ -199,7 +200,7 @@ renv_lockfile_create_impl <- function(project, type, libpaths, packages, exclude
   packages <- packages %||% renv_snapshot_dependencies(
     project = project,
     type = type,
-    dev = FALSE
+    dev = dev
   )
 
   # expand the recursive dependencies of these packages
@@ -214,8 +215,11 @@ renv_lockfile_create_impl <- function(project, type, libpaths, packages, exclude
   missing <- setdiff(packages, c(names(records), ignored))
 
   # cancel automatic snapshots if we have missing packages
-  if (length(missing) && the$auto_snapshot_running)
-    invokeRestart("cancel")
+  if (length(missing) && the$auto_snapshot_running) {
+    cancel <- findRestart("cancel")
+    if (isRestart(cancel))
+      invokeRestart(cancel)
+  }
 
   # give user a chance to handle missing packages, if any
   #
@@ -254,9 +258,9 @@ renv_lockfile_compact <- function(lockfile) {
   records <- renv_lockfile_records(lockfile)
   remotes <- map_chr(records, renv_record_format_remote)
 
-  remotes <- csort(remotes)
+  remotes <- remotes[sort(names(remotes))]
 
-  formatted <- sprintf("  \"%s\"", remotes)
+  formatted <- sprintf("  %s = \"%s\"", format(names(remotes)), remotes)
   joined <- paste(formatted, collapse = ",\n")
 
   all <- c("renv::use(", joined, ")")
