@@ -1,26 +1,12 @@
 
-# tools for interacting with the R package records encoded
-# within a lockfile
-renv_records <- function(records) {
-  if (inherits(records, "renv_lockfile"))
-    return(records$Packages)
-  records
-}
-
-`renv_records<-` <- function(x, value) {
-  x$Packages <- filter(value, Negate(empty))
-  x
-}
-
 renv_records_select <- function(records, actions, action) {
-  records <- renv_records(records)
+  records <- renv_lockfile_records(records)
   matching <- actions[actions %in% action]
   keep(records, names(matching))
 }
 
 renv_records_sort <- function(records) {
-  renv_scope_locale("LC_COLLATE", "C")
-  records[order(names(records))]
+  records[csort(names(records))]
 }
 
 renv_records_override <- function(records) {
@@ -96,7 +82,7 @@ renv_record_validate <- function(package, record) {
     return(record)
 
   # if we're running tests, or in CI, then report
-  if (renv_tests_running() || !is.na(Sys.getenv("CI", unset = NA))) {
+  if (renv_tests_running() || renv_envvar_exists("CI")) {
     fmt <- "! Internal error: unexpected record for package '%s'"
     writef(fmt, package)
     print(record)
@@ -119,6 +105,9 @@ renv_record_format_remote <- function(record) {
 
 renv_record_format_short <- function(record, versioned = FALSE) {
 
+  if (is.null(record))
+    return(renv_record_placeholder())
+
   remotes <- c("RemoteUsername", "RemoteRepo")
   if (all(remotes %in% names(record))) {
     remote <- renv_record_format_short_remote(record)
@@ -152,13 +141,16 @@ renv_record_format_short_remote <- function(record) {
 
 }
 
-renv_record_format_pair <- function(lhs, rhs) {
+renv_record_format_pair <- function(lhs, rhs, separator = "->") {
+
+  placeholder <- renv_record_placeholder()
 
   # check for install / remove
-  if (is.null(lhs))
-    return(sprintf("[* -> %s]", renv_record_format_short(rhs)))
-  else if (is.null(rhs))
-    return(sprintf("[%s -> *]", renv_record_format_short(lhs)))
+  if (is.null(lhs) || is.null(rhs)) {
+    lhs <- renv_record_format_short(lhs)
+    rhs <- renv_record_format_short(rhs)
+    return(sprintf("[%s %s %s]", lhs, separator, rhs))
+  }
 
   map <- list(
     Source         = "src",
@@ -197,10 +189,10 @@ renv_record_format_pair <- function(lhs, rhs) {
     identical(lhs$Repository, rhs$Repository)
 
   if (isrepo) {
-    fmt <- "[%s -> %s]"
+    fmt <- "[%s %s %s]"
     lhsf <- renv_record_format_short(lhs)
     rhsf <- renv_record_format_short(rhs)
-    return(sprintf(fmt, lhsf, rhsf))
+    return(sprintf(fmt, lhsf, separator, rhsf))
   }
 
   # check for only sha changed
@@ -210,60 +202,60 @@ renv_record_format_pair <- function(lhs, rhs) {
 
   if (usesha) {
 
-    user <- lhs$RemoteUsername %||% "*"
-    repo <- lhs$RemoteRepo %||% "*"
+    user <- lhs$RemoteUsername %||% placeholder
+    repo <- lhs$RemoteRepo %||% placeholder
     spec <- paste(user, repo, sep = "/")
 
-    ref <- lhs$RemoteRef %||% "*"
+    ref <- lhs$RemoteRef %||% placeholder
     if (!ref %in% c("master", "*"))
       spec <- paste(spec, ref, sep = "@")
 
-    fmt <- "[%s: %s -> %s]"
-    lsha <- substring(lhs$RemoteSha %||% "*", 1L, 8L)
-    rsha <- substring(rhs$RemoteSha %||% "*", 1L, 8L)
+    fmt <- "[%s: %s %s %s]"
+    lsha <- substring(lhs$RemoteSha %||% placeholder, 1L, 8L)
+    rsha <- substring(rhs$RemoteSha %||% placeholder, 1L, 8L)
 
-    return(sprintf(fmt, spec, lsha, rsha))
+    return(sprintf(fmt, spec, lsha, separator, rsha))
 
   }
 
   # check for only source change
   if (setequal(changed, "Source")) {
-    fmt <- "[%s: %s -> %s]"
-    ver <- lhs$Version %||% "*"
-    lhsf <- lhs$Source %||% "*"
-    rhsf <- rhs$Source %||% "*"
-    return(sprintf(fmt, ver, lhsf, rhsf))
+    fmt <- "[%s: %s %s %s]"
+    ver <- lhs$Version %||% placeholder
+    lhsf <- lhs$Source %||% placeholder
+    rhsf <- rhs$Source %||% placeholder
+    return(sprintf(fmt, ver, lhsf, separator, rhsf))
   }
 
   # check only version changed
   if (setequal(changed, "Version")) {
-    fmt <- "[%s -> %s]"
-    lhsf <- lhs$Version %||% "*"
-    rhsf <- rhs$Version %||% "*"
-    return(sprintf(fmt, lhsf, rhsf))
+    fmt <- "[%s %s %s]"
+    lhsf <- lhs$Version %||% placeholder
+    rhsf <- rhs$Version %||% placeholder
+    return(sprintf(fmt, lhsf, separator, rhsf))
   }
 
   # if the source has changed, highlight that
   if ("Source" %in% changed) {
-    fmt <- "[%s -> %s]"
+    fmt <- "[%s %s %s]"
     lhsf <- renv_record_format_short(lhs)
     rhsf <- renv_record_format_short(rhs)
-    return(sprintf(fmt, lhsf, rhsf))
+    return(sprintf(fmt, lhsf, separator, rhsf))
   }
 
   # otherwise, report each diff individually
   diffs <- map_chr(changed, function(field) {
 
-    lhsf <- lhs[[field]] %||% "*"
-    rhsf <- rhs[[field]] %||% "*"
+    lhsf <- lhs[[field]] %||% placeholder
+    rhsf <- rhs[[field]] %||% placeholder
 
     if (field == "RemoteSha") {
       lhsf <- substring(lhsf, 1L, 8L)
       rhsf <- substring(rhsf, 1L, 8L)
     }
 
-    fmt <- "%s: %s -> %s"
-    sprintf(fmt, map[[field]], lhsf, rhsf)
+    fmt <- "%s: %s %s %s"
+    sprintf(fmt, map[[field]], lhsf, separator, rhsf)
   })
 
   sprintf("[%s]", paste(diffs, collapse = "; "))
