@@ -78,7 +78,7 @@ renv_update_find_github <- function(records) {
       "GITHUB_PAT is unset. Updates may fail due to GitHub's API rate limit.",
       "",
       "To increase your GitHub API rate limit:",
-      "- Use `usethis::browse_github_pat()` to create a Personal Access Token (PAT).",
+      "- Use `usethis::create_github_token()` to create a Personal Access Token (PAT).",
       "- Use `usethis::edit_r_environ()` and add the token as `GITHUB_PAT`.",
       sep = "\n"
     )
@@ -114,8 +114,14 @@ renv_update_find_github_impl <- function(record) {
   if (sha == record$RemoteSha)
     return(NULL)
 
+  url <- record$RemoteUrl %||% {
+    origin <- fsub("api.github.com", "github.com", renv_retrieve_origin(host))
+    parts <- c(origin, user, repo)
+    paste(parts, collapse = "/")
+  }
+
   # get updated record
-  desc <- renv_remotes_resolve_github_description(host, user, repo, subdir, sha)
+  desc <- renv_remotes_resolve_github_description(url, host, user, repo, subdir, sha)
   current <- list(
     Package        = desc$Package,
     Version        = desc$Version,
@@ -266,6 +272,7 @@ update <- function(packages = NULL,
 
   project <- renv_project_resolve(project)
   renv_project_lock(project = project)
+  renv_scope_verbose_if(prompt)
 
   # resolve library path
   libpaths <- renv_libpaths_resolve(library)
@@ -295,7 +302,7 @@ update <- function(packages = NULL,
   if (!empty(missing)) {
 
     if (prompt || renv_verbose()) {
-      renv_pretty_print(
+      caution_bullets(
         "The following package(s) are not currently installed:",
         missing,
         "The latest available versions of these packages will be installed instead."
@@ -399,6 +406,7 @@ update <- function(packages = NULL,
     packages = updates,
     library  = libpaths,
     rebuild  = rebuild,
+    prompt   = prompt,
     project  = project
   )
 
@@ -444,7 +452,7 @@ renv_update_errors_emit_impl <- function(key, preamble, postamble) {
     sprintf("%s: %s", format(package), errmsg)
   })
 
-  renv_pretty_print(
+  caution_bullets(
     preamble = preamble,
     values = messages,
     postamble = postamble
