@@ -31,7 +31,7 @@ renv_watchdog_enabled_impl <- function() {
   if (getRversion() < "4.0.0")
     return(FALSE)
 
-  # skip if explicitly disabled via envvar
+  # allow override via environment variable
   enabled <- Sys.getenv("RENV_WATCHDOG_ENABLED", unset = NA)
   if (!is.na(enabled))
     return(truthy(enabled))
@@ -98,14 +98,7 @@ renv_watchdog_start_impl <- function() {
   name <- .packageName
   pid <- Sys.getpid()
 
-  env <- list(
-    name    = name,
-    library = library,
-    pid     = pid,
-    port    = port
-  )
-
-  code <- substitute(env = env, {
+  code <- inject({
     client <- list(pid = pid, port = port)
     host <- loadNamespace(name, lib.loc = library)
     renv <- if (!is.null(host$renv)) host$renv else host
@@ -119,25 +112,28 @@ renv_watchdog_start_impl <- function() {
   stdout <- stderr <- if (truthy(debugging)) "" else FALSE
 
   # launch the watchdog
-  system2(
-    command = R(),
-    args = c("--vanilla", "-s", "-f", renv_shell_path(script)),
-    stdout = stdout,
-    stderr = stderr,
-    wait = FALSE
-  )
+  local({
+    renv_scope_envvars(RENV_PROCESS_TYPE = "watchdog-server")
+    system2(
+      command = R(),
+      args = c("--vanilla", "-s", "-f", renv_shell_path(script)),
+      stdout = stdout,
+      stderr = stderr,
+      wait = FALSE
+    )
+  })
 
   # wait for connection from watchdog server
   dlog("watchdog", "watchdog process launched; waiting for message")
-  conn <- catch(renv_socket_accept(socket, open = "rb", timeout = 10))
+  conn <- catch(renv_socket_accept(socket, open = "rb", timeout = 10L))
   if (inherits(conn, "error")) {
     dlog("watchdog", paste("error connecting to watchdog:", conditionMessage(conn)))
     return(FALSE)
   }
 
   # store information about the running process
+  defer(close(conn))
   the$watchdog_process <- unserialize(conn)
-  close(conn)
 
   # return TRUE to indicate process was started
   dlog("watchdog", "watchdog message received [pid == %i]", the$watchdog_process$pid)
